# Shiro Inequality Prover (ShiroIn)
A Python library for proving polynomial inequalities. It uses SciPy and SymPy.

## Prerequisites
* Python >=3.5
* pip
* git (if you install from GitHub)
* Jupyter Notebook (recommended way of using ShiroIn)


## Installation
Copy one of these commands in terminal/cmd.
* Install from PyPI repository.
```pip install shiroin```
* Install from GitHub.
```pip install git+https://github.com/urojony/shiroin```

If you can't install libraries (for example you don't have administrator rights), try to add `--user` to command.
Note that ShiroIn works only for python3, if your default python is python2, then you should probably write `pip3` instead of `pip`.

You can also copy shiroin/__init__.py file to your computer and rename it to shiroin.py, but then you have to add directory with this file to PYTHONPATH or navigate to this directory each time before running python in terminal/cmd.

## Tutorial 
The tutorial is in the [tutorial.ipynb](https://github.com/urojony/shiroin/blob/master/tutorial.ipynb) file. You can also check [examples.py](https://github.com/urojony/shiroin/blob/master/examples.py) for more examples of usage and [statistics.ipynb](https://github.com/urojony/shiroin/blob/master/statistics.ipynb) for some approaches to automate proving inequalities even more.
